@@ -3,9 +3,11 @@ module Main (main) where
 import Test.Framework (defaultMain)
 import Text.RSS.Tests (rssTests)
 import Text.Atom.Tests (atomTests)
+import Text.Feed.Util.Tests (feedUtilTests)
 
 main :: IO ()
 main = defaultMain
   [ rssTests
   , atomTests
+  , feedUtilTests
   ]
